library scale_size;

import 'package:flutter/widgets.dart';

/// A class to help you scale your design on bigger or smaller screens to achieve the same design look.
class ScaleSize {
  /// Get status bar height
  static double statusBarHeight = 0;
  /// Get navigation bar height
  static double navigationBarHeight = 0;
  /// Get screen width
  static double screenWidth = 0;
  /// Get screen height
  static double screenHeight = 0;
  static double _designWidth = 0;

  /// Setup the screen with a [context] and the [designWidth] you will use.
  /// So, if you have a design width = 360. You will pass first the context
  /// then the designWidth.
  /// init(context, designWidth = 360)
  static void init(BuildContext context, {double designWidth = 360}) {
    ScaleSize._designWidth = designWidth;
    if (screenWidth > 0) {
      return;
    }
    MediaQueryData mediaQueryData = MediaQuery.of(context);
    statusBarHeight = mediaQueryData.padding.top;
    navigationBarHeight = mediaQueryData.padding.bottom;
    screenWidth = mediaQueryData.size.width;
    screenHeight = mediaQueryData.size.height;
  }

  /// Get the number scaled vertically.
  /// If you want change current designWidth, you will pass [size] and [designWidth].
  /// get(size, designWidth = 360)
  static double get(double size, {double designWidth = 0}) {
    if (designWidth == 0 && ScaleSize._designWidth == 0) {
      return size;
    }
    return size * ScaleSize.screenWidth / (designWidth == 0 ? ScaleSize._designWidth : designWidth);
  }
}
